import { computed } from 'vue'
import { storeToRefs } from 'pinia'
import { useSubmissionStore, useFormStore } from '@vue-unistra/formbuilder'

import { LAYOUT_COMPONENTS } from '@/stores/template'

import type { Metadata } from '#/item'
import type { StartField } from '@vue-unistra/formbuilder/types/Form'
import type { LevelField, ReferentialField } from '#/referential'

type MetaField = StartField | LevelField

export const useMetaSave = () => {
  const submitStore = useSubmissionStore()

  const formStore = useFormStore()

  const { submission } = storeToRefs(submitStore as any)

  function getTitle() {return  submission.value.title}

  const inputFields = computed<MetaField[]>(() => {
    return (Object.values(formStore.getFields) as MetaField[])
        .filter(f => !LAYOUT_COMPONENTS.includes(f.component))
  })

  const storedMetadata = computed(() => {
    return inputFields.value.reduce((meta: Metadata[], field) => {
      const {
        id,
        name,
        repeatable,
        multiple,
        options,
        parentId,
        levelId
      } = field as LevelField

      const metaField: Metadata = {
        id,
        name: name || id,
        value: null
      }

      if (multiple) {
        metaField.multiple = true
      }

      if (levelId) {
        // get referentialId from parent field
        const referentialField = formStore.fields[parentId] as ReferentialField
        metaField.referentialId = referentialField.referentialId
        metaField.levelId = levelId
      }

      if (repeatable) {
        metaField.repeatable = true
      }
      if (options) {
        metaField.isOption = true
      }

      if (Object.hasOwn(submission.value, metaField.name)) {
        metaField.value = submission.value[metaField.name]
      }
      meta.push(metaField)
      return meta
    }, [])
  })

  function resetStores() {
    formStore.$reset()
    submitStore.$reset()
  }

  return {
    resetStores,
    getTitle,
    inputFields,
    storedMetadata,
  }
}
