import { computed } from 'vue'
import { useI18n } from 'vue-i18n'

import ReferentialComponent from '@/components/template/referential/FormBuilderComponent.vue'
import ReferentialSelect from '@/components/template/referential/LevelSelect.vue'
import ReferentialSettings from '@/components/template/referential/ReferentialSettings.vue'

import type { CustomComponents } from '@vue-unistra/formbuilder'
import type { ControlsCustom } from '@vue-unistra/formbuilder/types/Controls'
import LevelSettings from '@/components/template/referential/LevelSettings.vue'

export function useReferentialComponent() {

  const { t } = useI18n()

  const referentialComponents: CustomComponents = fieldName => {
    switch (fieldName) {
      case 'ReferentialComponent':
        return ReferentialComponent
      case 'ReferentialSelect':
        return ReferentialSelect
    }
  }

  const referentialSettings: CustomComponents = fieldName => {
    switch (fieldName) {
      case 'ReferentialTab':
        return ReferentialSettings
      case 'LevelTab':
        return LevelSettings
    }
  }

  const referentialControls = computed<ControlsCustom>(() => {
    return {
      ReferentialComponent: {
        name: t('referential.field'),
        localeName: '',
        hasInternationalization: false,
        icon: 'mdi-family-tree',
        id: 'ReferentialComponent',
        toAdd: { component: 'ReferentialComponent' },
        settingsModalTabs: [
          {
            name: t('referential.label'),
            component: 'ReferentialTab',
          },
          {
            name: 'API',
            component: 'ApiTab',
          },
          {
            name: 'Conditional',
            component: 'ConditionalTab',
          },
        ],
        usfSubtypes: [],
        usfType: 'custom'
      },
      ReferentialSelect: {
        name: t('referential.select'),
        localeName: '',
        hasInternationalization: false,
        icon: 'mdi-family-tree',
        id: 'ReferentialSelect',
        notInControlList: true,
        toAdd: { component: 'ReferentialSelect' },
        settingsModalTabs: [
          {
            name: t('referential.label'),
            component: 'LevelTab',
          },
          {
            name: 'API',
            component: 'ApiTab',
          },
          {
            name: 'Conditional',
            component: 'ConditionalTab',
          },
        ],
        usfSubtypes: [],
        usfType: 'custom'
      },
    }
  })

  return {
    referentialComponents,
    referentialControls,
    referentialSettings,
  }
}
