import { ref } from 'vue'

const edition = ref<{
  opened: boolean;
  translation: {id: string, name: string} | null;
  name: {id: string, isLevel: boolean} | null;
}>({
  opened: false,
  translation: null,
  name: null,
})


export function useReferentialEdition () {
  function editTranslation(objectId: string, objectName: string) {
    edition.value = {
      opened: true,
      translation: {
        id: objectId,
        name: objectName
      },
      name: null
    }
  }

  function editNodeName(nodeId: string) {
    edition.value = {
      opened: true,
      translation: null,
      name: {
        id: nodeId,
        isLevel: false,
      }
    }
  }

  function editLevelName(levelId: string) {
    edition.value = {
      opened: true,
      translation: null,
      name: {
        id: levelId,
        isLevel: true,
      }
    }
  }

  function closeDialog() {
    edition.value = {
      opened: false,
      translation: null,
      name: null,
    }
  }

  return {
    editLevelName,
    editTranslation,
    editNodeName,
    edition,
    closeDialog,
  }
}
