import type { Hierarchy } from './referential'

export interface SearchQueryParams {
  q: string;
  projectIds?: string;
}

export interface Hits {
  value: number;
  relation: string;
}

export interface SearchResponse {
  query: string;
  hits: Hits;
  results: SearchResponseResult[];
  aggregations: SearchResponseAggregations;
}

export interface ResultBase {
  id: string;
  title: string;
  description: string;
  thumbnail?: string;
  isPublic: boolean;
  score: number;
}

export type DocType = 'project' | 'set' | 'item'

export interface ResultItem extends ResultBase {
  docType: 'item';
  creator: Hierarchy;
}

export interface ResultSet extends ResultItem {
  docType: 'set';
  itemsCount?: number;
  publicItemsCount: number;
}

export interface ResultProject extends Omit<ResultSet, 'creator'> {
  docType: 'project';
  setsCount?: number;
  publicSetsCount: number;
  managers: string[];
}

export type SearchResponseResult = ResultItem | ResultSet | ResultProject

export interface SearchResult extends Pick<SearchResponseResult, 'id' | 'title' | 'description' | 'thumbnail'> {
  subtitles?: string[];
  chip?: string;
}

export interface SearchResponseAggregations {
  filternames: Record<string, string>[];
  aggregations: Record<string, Bucket[]>;
}

export interface Bucket {
  key: string;
  keyAsString?: string;
  docCount: number;
  value: boolean;
}

export interface Aggregation {
  filterName: string;
  buckets: string[];
  name: string;
}

export interface Param {
  key: string;
  value: string;
}

export interface Pagination {
  page: number;
  pageSize: number;
}

export interface SearchStoreState {
  toSearch: string;
  params: Record<string, Param>;
  results: SearchResults;
  aggregations: Record<string, Aggregation>;
  buckets: Record<string, Bucket>;
  hits: Hits;
  pagination: Pagination
}
